@@ -2,7 +2,7 @@ package Lingua::EN::Inflexion;
 use 5.010; use warnings;
 use Carp;
 
-our $VERSION = '0.000005';
+our $VERSION = '0.000006';
 
 # Import noun, verb, and adj classes...
 use Lingua::EN::Inflexion::Term;
@@ -170,7 +170,7 @@ Lingua::EN::Inflexion - Inflect English nouns, verbs, adjectives, and articles
 
 =head1 VERSION
 
-This document describes Lingua::EN::Inflexion version 0.000005
+This document describes Lingua::EN::Inflexion version 0.000006
 
 
 =head1 SYNOPSIS
@@ -785,7 +785,7 @@ specific when the count is less than two:
               # "a match was found"     if $count == 1
               # "matches were found"    if $count > 1
 
-I<Mnemonic:> C<s> for "don't display" or "disguised definition" or "delete".
+I<Mnemonic:> C<d> for "don't display" or "disguised definition" or "delete".
 
 =back
 
@@ -843,7 +843,7 @@ active count (i.e. regardless of the value in any preceding C<< <#:...> >>.
 
 This is sometimes useful for constructions such as:
 
-    say inflect "Searching for <Ns:$target>.....found $count";
+    say inflect "Searching for <#a:> <Ns:$target>.....found $count";
               # "Searching for a walrus...found 1"
               # "Searching for an appendix...found 4"
               # "Searching for a denarius...found 12742"
@@ -882,8 +882,7 @@ That's useful because it keeps markup relatively concise:
 
 but it's also a problem because it makes the meaning of each
 markup hard to remember six months later. So C<inflect()> 
-also allows you to specify options mwith complete
-words, like so:
+also allows you to specify options with complete words, like so:
 
     say inflect "<#AnNoWords:$count> <NounClassical:$target> <Verb:were> found";
 
@@ -1160,7 +1159,7 @@ then the following behaviour has been specified:
     noun('octopus')->classical    "octopus"    "octopuses"
 
 That is, the module will always use the first specification for any
-singular-to-plural inflexion of "octopus" (see the L<subsequent
+singular-to-plural inflexion of "octopus" (see the L<preceding
 discussion|"octopi"> for an explanation of why this is the only
 appropriate behaviour for this particular word.)
 
@@ -1347,7 +1346,7 @@ Damian Conway  C<< <DCONWAY@CPAN.org> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2014, Damian Conway C<< <DCONWAY@CPAN.org> >>. All rights reserved.
+Copyright (c) 2014-2016, Damian Conway C<< <DCONWAY@CPAN.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
